@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,8 +21,9 @@
 
 package com.openexchange.authentication.application.storage.rdb;
 
-import static com.openexchange.authentication.LoginExceptionCodes.INVALID_CREDENTIALS_MISSING_CONTEXT_MAPPING;
+import static com.openexchange.authentication.LoginExceptionCodes.INVALID_CREDENTIALS;
 import java.util.UUID;
+import org.slf4j.Logger;
 import com.openexchange.authentication.Authenticated;
 import com.openexchange.authentication.NamePart;
 import com.openexchange.authentication.application.ApplicationPassword;
@@ -52,6 +53,11 @@ import com.openexchange.tools.session.ServerSessionAdapter;
  */
 public abstract class AbstractAppPasswordStorage {
 
+    /** Simple class to delay initialization until needed */
+    private static class LoggerHolder {
+        static final Logger LOG = org.slf4j.LoggerFactory.getLogger(AbstractAppPasswordStorage.class);
+    }
+
     protected final ServiceLookup lookup;
     protected final AppPasswordGenerator passwordGenerator;
 
@@ -220,7 +226,8 @@ public abstract class AbstractAppPasswordStorage {
         try {
             loginContextInfo = namePart.getFrom(userInfo, Authenticated.DEFAULT_CONTEXT_INFO);
         } catch (IllegalArgumentException e) {
-            throw INVALID_CREDENTIALS_MISSING_CONTEXT_MAPPING.create(userInfo);
+            LoggerHolder.LOG.debug("Missing user mapping for user \"{}\". Login failed.", userInfo);
+            throw INVALID_CREDENTIALS.create();
         }
         int contextId = getContextService().getContextId(loginContextInfo);
         if (-1 == contextId) {
@@ -231,7 +238,8 @@ public abstract class AbstractAppPasswordStorage {
                 }
             }
             if (-1 == contextId) {
-                throw INVALID_CREDENTIALS_MISSING_CONTEXT_MAPPING.create(loginContextInfo);
+                LoggerHolder.LOG.debug("Missing context mapping for context \"{}\". Login failed.", loginContextInfo);
+                throw INVALID_CREDENTIALS.create();
             }
         }
         return contextId;
