@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,8 +21,8 @@
 
 package com.openexchange.authentication.application.storage.rdb;
 
-import java.security.SecureRandom;
 import java.util.regex.Pattern;
+import com.openexchange.java.CryptoUtil;
 import com.openexchange.java.Strings;
 
 /**
@@ -37,14 +37,11 @@ public class AppPasswordGenerator {
     private static final char[] PASSWORD_FORMAT = "xxxx-xxxx-xxxx-xxxx".toCharArray();
     private static final Pattern PASSWORD_PATTERN = Pattern.compile("[a-z]{4}-[a-z]{4}-[a-z]{4}-[a-z]{4}");
 
-    private final SecureRandom random;
-
     /**
      * Initializes a new {@link AppPasswordGenerator}.
      */
     public AppPasswordGenerator() {
         super();
-        this.random = new SecureRandom();
     }
 
     /**
@@ -56,7 +53,7 @@ public class AppPasswordGenerator {
         StringBuilder stringBuilder = new StringBuilder(PASSWORD_FORMAT.length);
         for (char c : PASSWORD_FORMAT) {
             if ('x' == c) {
-                stringBuilder.append(PASSWORD_CHARS[random.nextInt(PASSWORD_CHARS.length)]);
+                stringBuilder.append(PASSWORD_CHARS[CryptoUtil.getSecureRandom().nextInt(PASSWORD_CHARS.length)]);
             } else {
                 stringBuilder.append(c);
             }
